@@ -48,6 +48,7 @@ BEGIN {
 		regular_archives => 1,
 		library_archives => 1,
 		name_alias_redirection => 1,
+		name_alias_resolving => 0,
 		debug_enabled => 1,
 		http_headers => 'Robots: nofollow, index, archive\n',
 		content_charset => "",
@@ -159,7 +160,7 @@ sub apply_config_immediately () {
 
 	# this should be done before url flags are parsed, so work with $ENV
 	$Config{template_set} = $1
-		if ($ENV{QUERY_STRING} || "") =~ /(?:^|[&?])template=([\w-]+)/
+		if ($ENV{QUERY_STRING} || $ARGV[1] || "") =~ /(?:^|[&?])template=([\w-]+)/
 			&& (-d "$Config{template_dir}/$1" || $1 eq "minimal");
 	# temporarily support the old name for backward compatibility
 	$Config{template_set} = "plain" if $Config{template_set} eq "minimal";
